@@ -1,80 +1,80 @@
 #' The adaptive fence procedure
-#' 
+#'
 #' This function implements the adaptive fence procedure to
-#' first find the optimal cstar value and then finds the 
+#' first find the optimal cstar value and then finds the
 #' corresponding best model as described in Jiang et. al.
 #' (2009) with some practical modifications.
-#' 
+#'
 #' The initial stepwise procedure performs forward stepwise model
-#' selection using the AIC and backward stepwise model selection 
-#' using BIC.  In general the backwise selection via the more 
+#' selection using the AIC and backward stepwise model selection
+#' using BIC.  In general the backwise selection via the more
 #' conservative BIC will tend to select a smaller model than that
 #' of the forward selection AIC approach.  The size of these two
 #' models is found, and we go two dimensions smaller and larger
 #' to estimate a sensible range of \code{c} values over which to
 #' perform a parametric bootstrap.
-#' 
+#'
 #' This procedure can take some time.  It is recommended that you start
-#' with a relatively small number of bootstrap samples (\code{B}) 
-#' and grid of boundary values (\code{n.c}) and increase both as 
+#' with a relatively small number of bootstrap samples (\code{B})
+#' and grid of boundary values (\code{n.c}) and increase both as
 #' required.
-#' 
-#' If you use \code{initial.stepwise=TRUE} then in general you will 
-#' need a smaller grid of boundary values than if you select 
+#'
+#' If you use \code{initial.stepwise=TRUE} then in general you will
+#' need a smaller grid of boundary values than if you select
 #' \code{initial.stepwise=FALSE}.
 #' It can be useful to check \code{initial.stepwise=FALSE} with a
 #' small number of bootstrap replications over a sparse grid to ensure
-#' that the \code{initial.stepwise=TRUE} has landed you in a reasonable 
+#' that the \code{initial.stepwise=TRUE} has landed you in a reasonable
 #' region.
-#' 
+#'
 #' The \code{best.only=FALSE} option when plotting the results of the
-#' adaptive fence is a modification to the adaptive fence procedure 
-#' which considers all models at a particular size that pass the fence 
+#' adaptive fence is a modification to the adaptive fence procedure
+#' which considers all models at a particular size that pass the fence
 #' hurdle when calculating the p* values.  In particular,
-#' for each value of c and at each bootstrap replication, 
+#' for each value of c and at each bootstrap replication,
 #' if a candidate model is found that passes the fence, then we look to see
-#' if there are any other models of the same size that also pass the fence.  
+#' if there are any other models of the same size that also pass the fence.
 #' If no other models of the same size pass the fence, then that model is
 #' allocated a weight of 1.  If there are two models that pass the fence, then
 #' the best model is allocated a weight of 1/2.  If three models pass the fence,
 #' the best model gets a weight of 1/3, and so on. After \code{B} bootstrap
 #' replications, we aggregate the weights by summing over the various models.
-#' The p* value is the maximum aggregated weight divided by the number of bootstrap 
+#' The p* value is the maximum aggregated weight divided by the number of bootstrap
 #' replications.
-#' This correction penalises the probability associated with the best model if 
+#' This correction penalises the probability associated with the best model if
 #' there were other models of the same size that also passed the fence hurdle.
 #' The rationale being that if a model has no redundant variables
-#' then it will be the only model at that size that passes the fence over a 
-#' range of values of c.  
-#' The result is more pronounced peaks which can help to determine 
+#' then it will be the only model at that size that passes the fence over a
+#' range of values of c.
+#' The result is more pronounced peaks which can help to determine
 #' the location of the correct peak and identify the optimal c*.
-#' 
+#'
 #' @param mf a fitted 'full' model, the result of a call
 #'   to lm or glm (and in the future lme or lmer).
 #' @param B number of bootstrap replications at each fence
 #'   boundary value
 #' @param n.c number of boundary values to be considered
-#' @param initial.stepwise logical.  Performs an initial stepwise 
+#' @param initial.stepwise logical.  Performs an initial stepwise
 #'   procedure to look for the range of model sizes where attention
 #'   should be focussed. See details for implementation.
 #' @param force.in the names of variables that should be forced
 #'   into all estimated models
 #' @param n.cores number of cores to be used when parallel
 #'   processing the bootstrap
-#' @param nvmax size of the largest model that can still be 
+#' @param nvmax size of the largest model that can still be
 #'   considered as a viable candidate.  Included for performance
 #'   reasons but if it is an active constraint it could lead to
 #'   missleading results.
-#' @param c.max manually specify the upper boundary limit. 
+#' @param c.max manually specify the upper boundary limit.
 #'   Only applies when \code{initial.stepwise=FALSE}.
 #' @param screen logical, whether or not to perform an initial
 #'   screen for outliers.  Highly experimental, use at own risk.
 #'   Default = FALSE.
 #' @param ... further arguments (currently unused)
-#' @references Jiang J., Nguyen T., Sunil Rao J. (2009), 
-#'   A simplified adaptive fence procedure, Statistics & 
+#' @references Jiang J., Nguyen T., Sunil Rao J. (2009),
+#'   A simplified adaptive fence procedure, Statistics &
 #'   Probability Letters, 79(5):625-629.  doi: 10.1016/j.spl.2008.10.014
-#'   
+#'
 #'   Jiang J., Sunil Rao J., Gu Z, Nguyen T. (2008),
 #'   Fence methods for mixed model selection, Annals of Statistics,
 #'   36(4):1669-1692. doi: 10.1214/07-AOS517
@@ -104,7 +104,7 @@
 af = function(mf,
               B=60, n.c=20,
               initial.stepwise=FALSE,
-              force.in=NULL, 
+              force.in=NULL,
               n.cores, nvmax, c.max, screen=FALSE,  ...){
   method="ML"
   af.call = match.call()
@@ -117,7 +117,7 @@ af = function(mf,
     model.type = "lm"
   }
   if(any(class(mf)=="glm")==TRUE){
-    family=family(mf)
+    family=stats::family(mf)
     if(!is.null(force.in)){
       warning("force.in is not implemented for glms")
     }
@@ -125,7 +125,7 @@ af = function(mf,
   } else if(class(mf)=="lm"){
     model.type="lm"
   }
-  m = mextract(mf,screen=screen) 
+  m = mextract(mf,screen=screen)
   fixed = m$fixed
   yname = m$yname
   family = m$family
@@ -134,46 +134,48 @@ af = function(mf,
   n = m$n
   Xy$initial.weights = m$wts
   initial.weights = m$wts
-  null.ff = as.formula(paste(yname,"~1"))
+  null.ff = stats::as.formula(paste(yname,"~1"))
   if(model.type=="glm"){
-    m0 = glm(null.ff, data = Xy, family=family, weights = initial.weights) 
-    mfstar = glm(fixed, data = Xy, family=family, weights = initial.weights) 
+    m0 = stats::glm(null.ff, data = Xy, family=family, weights = initial.weights)
+    mfstar = stats::glm(fixed, data = Xy, family=family, weights = initial.weights)
   } else {
-    m0 = lm(null.ff, data = Xy, weights = initial.weights) 
-    mfstar = lm(fixed, data = Xy, weights = initial.weights) 
+    m0 = stats::lm(null.ff, data = Xy, weights = initial.weights)
+    mfstar = stats::lm(fixed, data = Xy, weights = initial.weights)
   }
   Qm0 = Qm(m0, method=method)
   Qmfstar = Qm(mfstar, method=method)
   if(!is.null(force.in)){
-    small.ff = as.formula(paste(yname,"~",paste(force.in,collapse="+")))
+    small.ff = stats::as.formula(paste(yname,"~",paste(force.in,collapse="+")))
   } else {
     small.ff = null.ff
   }
   if (initial.stepwise) {
     if(model.type=="glm"){
-      small.mod = glm(small.ff, data = Xy, family=family, weights = initial.weights)
+      small.mod = stats::glm(small.ff, data = Xy, family=family, weights = initial.weights)
     } else {
-      small.mod = lm(small.ff, data = Xy, weights = initial.weights)
+      small.mod = stats::lm(small.ff, data = Xy, weights = initial.weights)
     }
     # backwards and forwards model selection using
     # BIC (conservative) and AIC (less conservative)
-    bwds.BIC = step(mfstar, 
+    bwds.BIC = stats::step(mfstar,
                     scope = list(lower=small.ff, upper=fixed),
                     direction="backward", k=log(n), trace=0)
-    fwds.BIC = step(small.mod, 
+    fwds.BIC = stats::step(small.mod,
                     scope = list(lower=small.ff, upper=fixed),
                     direction="forward", k=log(n), trace=0)
-    k.min = max(min(length(bwds.BIC$coef),length(fwds.BIC$coef))-2,1)
-    bwds.AIC = step(mfstar, 
+    bwds.AIC = stats::step(mfstar,
                     scope = list(lower=small.ff, upper=fixed),
                     direction="backward", k=2, trace=0)
-    fwds.AIC = step(small.mod, 
-                    scope = list(lower=small.ff, upper=fixed),
-                    direction="forward", k=2, trace=0)
-    k.max = min(max(length(bwds.AIC$coef),length(fwds.AIC$coef))+2,kf)  
+    fwds.AIC = stats::step(small.mod,
+                    scope = list(lower = small.ff, upper = fixed),
+                    direction = "forward", k = 2, trace = 0)
+    k.vals = c(length(bwds.BIC$coef),length(fwds.BIC$coef),
+               length(bwds.AIC$coef),length(fwds.AIC$coef))
+    k.min = max(min(k.vals) - 2, 1)
+    k.max = min(max(k.vals) + 2, kf)
     k.range = list(k.min=k.min,k.max=k.max)
-    Q.range = qrange(k.range=k.range, data=Xy, 
-                     yname=yname, fixed=fixed, 
+    Q.range = qrange(k.range=k.range, data=Xy,
+                     yname=yname, fixed=fixed,
                      method=method, force.in=force.in,
                      model.type = model.type,
                      family = family)
@@ -188,7 +190,7 @@ af = function(mf,
     c.range = seq(c.min,c.max,length.out=n.c)
     if(missing(nvmax)) nvmax = kf
   }
-  
+
   if(missing(n.cores)) n.cores = max(detectCores()-1,1)
   cl.af = makeCluster(n.cores)
   doParallel::registerDoParallel(cl.af)
@@ -196,17 +198,17 @@ af = function(mf,
   p.star.all = foreach(j = 1:n.c, .combine=rbind, .packages = c("mplot")) %dopar% {
     fence.mod = list()
     fence.rank = list()
-    ystar = simulate(object=mfstar,nsim=B)
+    ystar = stats::simulate(object=mfstar,nsim=B)
     initial.weights <<- m$wts
     if(model.type=="glm"){
       for(i in 1:B){
         Xy[yname] = ystar[,i]
         mfstarB = do.call("glm",list(fixed,data=Xy,family=family, weights = initial.weights))
-        fms = glmfence(mfstarB, cstar=c.range[j], 
+        fms = glmfence(mfstarB, cstar=c.range[j],
                        trace=FALSE, nvmax=nvmax, adaptive=TRUE)
         fence.mod = c(fence.mod,fms)
         fence.rank = c(fence.rank,1:length(fms))
-      } 
+      }
     } else {
       for(i in 1:B){
         Xy[yname] = ystar[,i]
@@ -215,17 +217,17 @@ af = function(mf,
                       nvmax = nvmax, force.in=force.in, adaptive=TRUE)
         fence.mod = c(fence.mod,fms)
         fence.rank = c(fence.rank,1:length(fms))
-      } 
+      }
     }
    process.fn(fence.mod,fence.rank)
   }
   stopCluster(cl.af)
-  
+
   # Another function that processes results within af function
-  # 
+  #
   # This function is used by the af function to process
   # the results when iterating over different boundary values
-  
+
   pstar.fn = function(input,type){
     if(type=="bo"){
       p.star = input[,1:2]
@@ -261,7 +263,7 @@ af = function(mf,
     mid = floor(mid)
     c.star = min(c.range[mid])
     if(model.type=="glm"){
-      afmod = glmfence(mf, cstar=c.star, 
+      afmod = glmfence(mf, cstar=c.star,
                        trace=FALSE, nvmax=nvmax)[[1]]
     } else {
       afmod = lmfence(mf, cstar=c.star, trace=FALSE,
@@ -281,10 +283,10 @@ af = function(mf,
   afout$screen = screen
   if(initial.stepwise){
     afout$initial.stepwise = list(
-      fwds.AIC = as.formula(fwds.AIC),
-      fwds.BIC = as.formula(fwds.BIC),
-      bwds.AIC = as.formula(bwds.AIC),
-      bwds.BIC = as.formula(bwds.BIC))
+      fwds.AIC = stats::as.formula(fwds.AIC),
+      fwds.BIC = stats::as.formula(fwds.BIC),
+      bwds.AIC = stats::as.formula(bwds.AIC),
+      bwds.BIC = stats::as.formula(bwds.BIC))
   } else {afout$initial.stepwise=NULL}
   afout$k.range = k.range
   class(afout) = "af"
@@ -292,15 +294,15 @@ af = function(mf,
 }
 
 #' Summary method for an af object
-#' 
-#' Provides comprehensive  output of the bootstrap results of an 
+#'
+#' Provides comprehensive  output of the bootstrap results of an
 #' af object.
-#' 
+#'
 #' @param object \code{af} object, the result of \code{\link{af}}
 #' @param best.only logical determining whether the output used the
 #'   standard fence approach of only considering the best models
-#'   that pass the fence (\code{TRUE}) or if it should take into 
-#'   account all models that pass the fence at each boundary 
+#'   that pass the fence (\code{TRUE}) or if it should take into
+#'   account all models that pass the fence at each boundary
 #'   value (\code{FALSE}).
 #' @param ... further arguments (currently unused)
 #' @export
@@ -311,7 +313,7 @@ summary.af = function (object,best.only=TRUE,...) {
   } else {
     xsub = object$all
   }
-  cat("\nCall:\n", paste(deparse(object$call), sep = "\n", collapse = "\n"), 
+  cat("\nCall:\n", paste(deparse(object$call), sep = "\n", collapse = "\n"),
       "\n\n", sep = "")
   cat("Adaptive fence model (c*=")
   cat(round(xsub$c.star,1))
@@ -344,42 +346,44 @@ summary.af = function (object,best.only=TRUE,...) {
 
 
 #' Plot diagnostics for an af object
-#' 
-#' Summary plot of the bootstrap results of an 
+#'
+#' Summary plot of the bootstrap results of an
 #' af object.
-#' 
+#'
 #' @param x \code{af} object, the result of \code{\link{af}}
-#' @param classic logical.  If \code{classic=TRUE} a 
+#' @param classic logical.  If \code{classic=TRUE} a
 #'   base graphics plot is provided instead of a googleVis plot.
 #'   Default is \code{classic=FALSE}.
 #' @param best.only logical determining whether the output used the
 #'   standard fence approach of only considering the best models
-#'   that pass the fence (\code{TRUE}) or if it should take into 
-#'   account all models that pass the fence at each boundary 
+#'   that pass the fence (\code{TRUE}) or if it should take into
+#'   account all models that pass the fence at each boundary
 #'   value (\code{FALSE}).
 #' @param pch plotting character, i.e., symbol to use
 #' @param html.only logical for use with shiny. With rmarkdown
 #'   using \code{op = options(gvis.plot.tag = "chart")} is better.
-#' @param width Width of the googleVis chart canvas area, in pixels. 
+#' @param width Width of the googleVis chart canvas area, in pixels.
 #'   Default: 800.
-#' @param height Height of the googleVis chart canvas area, in pixels. 
+#' @param height Height of the googleVis chart canvas area, in pixels.
 #'   Default: 400.
-#' @param chartWidth googleVis chart area width.  
-#'   A simple number is a value in pixels; 
-#'   a string containing a number followed by \code{\%} is a percentage. 
+#' @param chartWidth googleVis chart area width.
+#'   A simple number is a value in pixels;
+#'   a string containing a number followed by \code{\%} is a percentage.
 #'   Default: \code{"60\%"}
-#' @param chartHeight googleVis chart area height. 
-#'   A simple number is a value in pixels; 
-#'   a string containing a number followed by \code{\%} is a percentage. 
+#' @param chartHeight googleVis chart area height.
+#'   A simple number is a value in pixels;
+#'   a string containing a number followed by \code{\%} is a percentage.
 #'   Default: \code{"80\%"}
 #' @param fontSize font size used in googleVis chart.  Default: 12.
 #' @param left space at left of chart (pixels?).  Default: "50".
 #' @param top space at top of chart (pixels?).  Default: "30".
-#' @param options If you want to specify the full set of googleVis 
+#' @param options If you want to specify the full set of googleVis
 #'   options.
-#' @param backgroundColor The background colour for the main area 
-#'   of the chart. A simple HTML color string, 
+#' @param backgroundColor The background colour for the main area
+#'   of the chart. A simple HTML color string,
 #'   for example: 'red' or '#00cc00'.  Default: 'transparent'
+#' @param legend.position legend position, e.g. \code{"topleft"}
+#'   or  \code{"bottomright"}
 #' @param ... further arguments (currently unused)
 #' @export
 # S3 method for class 'af'
@@ -390,6 +394,7 @@ plot.af = function(x,pch,classic=FALSE,
                    left=50,top=30,chartWidth="60%",
                    chartHeight="80%",
                    backgroundColor = 'transparent',
+                   legend.position = "topleft",
                    options=NULL,...){
   if(best.only){
     x = x$bestOnly
@@ -398,24 +403,24 @@ plot.af = function(x,pch,classic=FALSE,
   }
   if(classic){
     if(missing(pch)) pch=19
-    par(mar=c(3.4,3.4,2.1,0.1),mgp=c(2.0, 0.75, 0))
-    plot(x$p.star[,1]~x$c.range,
+    graphics::par(mar=c(3.4,3.4,2.1,0.1),mgp=c(2.0, 0.75, 0))
+    graphics::plot(x$p.star[,1]~x$c.range,
          ylim=c(0,1), pch=pch,
          col=x$p.star[,3],
          ylab = "p*", xlab = "c")
-    legend("topleft",legend=unique(x$p.star[,2]),
+    graphics::legend(legend.position, legend=unique(x$p.star[,2]),
            pch=pch,col=unique(x$p.star[,3]),bty="n")
-    axis(side=3, at=x$c.star, 
+    graphics::axis(side=3, at=x$c.star,
          labels=paste("c*=", round(x$c.star,1),sep=""))
   } else {
-    dat <- matrix(NA, nrow = nrow(x$p.star), 
+    dat <- matrix(NA, nrow = nrow(x$p.star),
                   ncol = nlevels(x$p.star$model) + 1)
     for(i in 1:nlevels(x$p.star$model)){
       lvl <- levels(x$p.star$model)[i]
       ind <- which(x$p.star$model == lvl)
       dat[ind, c(1, i+1)] <- x$p.star$pstar[ind]
     }
-    plot.dat = data.frame(c.range = as.numeric(x$c.range), 
+    plot.dat = data.frame(c.range = as.numeric(x$c.range),
                           dat[,-1])
     colnames(plot.dat) = c("c.range",levels(x$p.star$model))
     plot.dat = round(plot.dat,2)
@@ -446,22 +451,22 @@ plot.af = function(x,pch,classic=FALSE,
     if(html.only){
       return(fplot)
     } else {
-      return(plot(fplot))
+      return(graphics::plot(fplot))
     }
   }
 }
 
 
 #' Print method for an af object
-#' 
-#' Prints basic output of the bootstrap results of an 
+#'
+#' Prints basic output of the bootstrap results of an
 #' af object.
-#' 
+#'
 #' @param x an \code{af} object, the result of \code{\link{af}}
 #' @param best.only logical determining whether the output used the
 #'   standard fence approach of only considering the best models
-#'   that pass the fence (\code{TRUE}) or if it should take into 
-#'   account all models that pass the fence at each boundary 
+#'   that pass the fence (\code{TRUE}) or if it should take into
+#'   account all models that pass the fence at each boundary
 #'   value (\code{FALSE}).
 #' @param ... further arguments (currently unused)
 #' @export
@@ -472,7 +477,7 @@ print.af = function (x, best.only=TRUE, ...) {
   } else {
     x = x$all
   }
-  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
+  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"),
       "\n\n", sep = "")
   cat("Adaptive fence model (c*=")
   cat(round(x$c.star,1))
@@ -481,4 +486,3 @@ print.af = function (x, best.only=TRUE, ...) {
   cat("\n\n")
   invisible(x)
 }
-
